Function ucs_async_modify_handler

pub unsafe extern "C" fn ucs_async_modify_handler(
    fd: c_int,
    events: ucs_event_set_types_t,
) -> ucs_status_t
@ingroup UCS_RESOURCE

Modify events mask for an existing event handler (event file).

@param fd File descriptor modify events for. @param events New set of events to wait on (UCS_EVENT_SET_EVxxx bits).

@return Error code as defined by @ref ucs_status_t.