Function ucs_async_remove_handler

pub unsafe extern "C" fn ucs_async_remove_handler(
    id: c_int,
    sync: c_int,
) -> ucs_status_t
@ingroup UCS_RESOURCE

Remove an event handler (Timer or event file).

@param id Timer/FD to remove. @param sync If nonzero, wait until the handler for this event is not running anymore. If called from the context of the callback, the handler will be removed immediately after the current callback returns.

@return Error code as defined by @ref ucs_status_t.