#[repr(C)]pub struct ucp_context_attr {
pub field_mask: u64,
pub request_size: size_t,
pub thread_mode: ucs_thread_mode_t,
pub memory_types: u64,
pub name: [c_char; 32],
}Expand description
@ingroup UCP_CONTEXT @brief Context attributes.
The structure defines the attributes that characterize the particular context.
Fields
field_mask: u64Mask of valid fields in this structure, using bits from @ref ucp_context_attr_field. Fields not specified in this mask will be ignored. Provides ABI compatibility with respect to adding new fields.
request_size: size_tSize of UCP non-blocking request. When pre-allocated request is used (e.g. in @ref ucp_tag_recv_nbr) it should have enough space to fit UCP request data, which is defined by this value.
thread_mode: ucs_thread_mode_tThread safe level of the context. For supported thread levels please see @ref ucs_thread_mode_t.
memory_types: u64Mask of which memory types are supported, for supported memory types please see @ref ucs_memory_type_t.
name: [c_char; 32]Tracing and analysis tools can use name to identify this UCX context.