#[repr(transparent)]pub struct uct_cb_param_flags(pub c_uint);Expand description
@ingroup UCT_RESOURCE @brief Flags for active message and tag-matching offload callbacks (callback’s parameters).
If UCT_CB_PARAM_FLAG_DESC flag is enabled, then data is part of a descriptor which includes the user-defined rx_headroom, and the callback may return UCS_INPROGRESS and hold on to that descriptor. Otherwise, the data can’t be used outside the callback. If needed, the data must be copied-out.
@verbatim descriptor data | | +———––+———————––+ | rx_headroom | payload | +———––+———————––+ @endverbatim
UCT_CB_PARAM_FLAG_FIRST and UCT_CB_PARAM_FLAG_MORE flags are relevant for @ref uct_tag_unexp_eager_cb_t callback only. The former value indicates that the data is the first fragment of the message. The latter value means that more fragments of the message yet to be delivered.
Tuple Fields
0: c_uintImplementations