#[repr(C)]pub struct uct_cm_remote_data {
pub field_mask: u64,
pub dev_addr: *const uct_device_addr_t,
pub dev_addr_length: size_t,
pub conn_priv_data: *const c_void,
pub conn_priv_data_length: size_t,
}Expand description
@ingroup UCT_CLIENT_SERVER @brief Data received from the remote peer.
The remote peer’s device address, the data received from it and their lengths. Used with the client-server API on a connection manager.
Fields
field_mask: u64Mask of valid fields in this structure, using bits from @ref uct_cm_remote_data_field. Fields not specified by this mask will be ignored.
dev_addr: *const uct_device_addr_tDevice address of the remote peer.
dev_addr_length: size_tLength of the remote device address.
conn_priv_data: *const c_voidPointer to the received data. This is the private data that was passed to @ref uct_ep_params_t::sockaddr_pack_cb.
conn_priv_data_length: size_tLength of the received data from the peer.