Struct uct_component_attr

#[repr(C)]
pub struct uct_component_attr { pub field_mask: u64, pub name: [c_char; 16], pub md_resource_count: c_uint, pub md_resources: *mut uct_md_resource_desc_t, pub flags: u64, }
@ingroup UCT_RESOURCE @brief UCT component attributes

This structure defines the attributes for UCT component. It is used for @ref uct_component_query

Fields

field_mask: u64

Mask of valid fields in this structure, using bits from @ref uct_component_attr_field. Fields not specified in this mask will be ignored. Provides ABI compatibility with respect to adding new fields.

name: [c_char; 16]

Component name

md_resource_count: c_uint

Number of memory-domain resources

md_resources: *mut uct_md_resource_desc_t

Array of memory domain resources. When used, it should be initialized prior to calling @ref uct_component_query with a pointer to an array, which is large enough to hold all memory domain resource entries. After the call, this array will be filled with information about existing memory domain resources. In order to allocate this array, you can call @ref uct_component_query twice: The first time would only obtain the amount of entries required, by specifying @ref UCT_COMPONENT_ATTR_FIELD_MD_RESOURCE_COUNT in field_mask. Then the array could be allocated with the returned number of entries, and passed to a second call to @ref uct_component_query, this time setting field_mask to @ref UCT_COMPONENT_ATTR_FIELD_MD_RESOURCES.

flags: u64

Flags as defined by UCT_COMPONENT_FLAG_xx.