#[repr(C)]pub struct uct_mem_alloc_params_t {
pub field_mask: u64,
pub flags: c_uint,
pub address: *mut c_void,
pub mem_type: ucs_memory_type_t,
pub mds: uct_mem_alloc_params_t__bindgen_ty_1,
pub name: *const c_char,
}Expand description
@ingroup UCT_MD @brief Parameters for allocating memory using @ref uct_mem_alloc
Fields
field_mask: u64Mask of valid fields in this structure, using bits from @ref uct_mem_alloc_params_field_t. Fields not specified in this mask will be ignored.
flags: c_uintMemory allocation flags, see @ref uct_md_mem_flags If UCT_MEM_ALLOC_PARAM_FIELD_FLAGS is not specified in field_mask, then (UCT_MD_MEM_ACCESS_LOCAL_READ | UCT_MD_MEM_ACCESS_LOCAL_WRITE) is used by default.
address: *mut c_voidIf @a address is NULL, the underlying allocation routine will choose the address at which to create the mapping. If @a address is non-NULL and UCT_MD_MEM_FLAG_FIXED is not set, the address will be interpreted as a hint as to where to establish the mapping. If @a address is non-NULL and UCT_MD_MEM_FLAG_FIXED is set, then the specified address is interpreted as a requirement. In this case, if the mapping to the exact address cannot be made, the allocation request fails.
mem_type: ucs_memory_type_tType of memory to be allocated.
mds: uct_mem_alloc_params_t__bindgen_ty_1name: *const c_charName of the allocated region, used to track memory usage for debugging and profiling. If UCT_MEM_ALLOC_PARAM_FIELD_NAME is not specified in field_mask, then “anonymous-uct_mem_alloc” is used by default.