#[repr(transparent)]pub struct uct_flush_flags(pub c_uint);Expand description
@ingroup UCT_RESOURCE @brief Flush modifiers.
Tuple Fields
0: c_uintImplementations
Sourceimpl uct_flush_flags
impl uct_flush_flags
Sourcepub const UCT_FLUSH_FLAG_LOCAL: uct_flush_flags
pub const UCT_FLUSH_FLAG_LOCAL: uct_flush_flags
< Guarantees that the data transfer is completed but the target buffer may not be updated yet.
Sourceimpl uct_flush_flags
impl uct_flush_flags
Sourcepub const UCT_FLUSH_FLAG_CANCEL: uct_flush_flags
pub const UCT_FLUSH_FLAG_CANCEL: uct_flush_flags
< The library will make a best effort attempt to cancel all uncompleted operations. However, there is a chance that some operations will not be canceled in which case the user will need to handle their completions through the relevant callbacks. After @ref uct_ep_flush with this flag is completed, the endpoint will be set to error state, and it becomes unusable for send operations and should be destroyed.